# dgx

Generate Dealergeek API

## Installation

Use pip to install the package:

```bash
pip install dgx
```

## Usage

This package allows to generate an API structure, with some basic libraries.

### New project

Create a new project

```bash
dgx -i my-app
```

### Add module

This package has some default modules that you can add.

- brand
- personnel

```bash
dgx -a brand
```


### New module

If you want create a module, can you write this command.

```bash
dgx -c my-module
```

### Delete project

You must be in the root folder of the project, my-app-project


```bash
dgx -d my-app
```
